# Thaispoon: Thai Spoonerism
 Thaispoon is the package for create simple spoonerinm text in Thai language.
 - **Website:** https://loolang.herokuapp.com/
 ## How to use
 > pip install Thaispoon <br>
 > from Thaispoon import Spoonerism
 > test = Spoonerism("กินอะไร").Spoon() 
 > print(test)
___
## Functions in Thaispoon
* Spoon() : used for create thai spoonerim
* Loolang()  : used for create Loo Language
